==> jc-1.4.0.tar.gz: polyglot/util/TransformingIterator.h <==
// public final class polyglot.util.TransformingIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class abf83ac6f164f8b4 polyglot_util_TransformingIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_TransformingIterator_H_
#define _JC_polyglot_util_TransformingIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_Transformation$object;

// Typedefs
typedef struct _jc_polyglot_util_TransformingIterator$sub_refs	_jc_polyglot_util_TransformingIterator$sub_refs;
typedef struct _jc_polyglot_util_TransformingIterator$sub_nonrefs	_jc_polyglot_util_TransformingIterator$sub_nonrefs;
typedef struct _jc_polyglot_util_TransformingIterator$refs	_jc_polyglot_util_TransformingIterator$refs;
typedef struct _jc_polyglot_util_TransformingIterator$nonrefs	_jc_polyglot_util_TransformingIterator$nonrefs;
typedef struct _jc_polyglot_util_TransformingIterator$object	_jc_polyglot_util_TransformingIterator$object;

typedef const struct _jc_polyglot_util_TransformingIterator$vmethods	_jc_polyglot_util_TransformingIterator$vmethods;
typedef const struct _jc_polyglot_util_TransformingIterator$vtable	_jc_polyglot_util_TransformingIterator$vtable;
typedef const struct _jc_polyglot_util_TransformingIterator$vtype	_jc_polyglot_util_TransformingIterator$vtype;

// Constructors
extern void _jc_polyglot_util_TransformingIterator$method$_init$687c4dce38d09c75(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_polyglot_util_TransformingIterator$method$_init$8a125fbc5dc09cc2(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_polyglot_util_TransformingIterator$method$_init$098c0fa7b235a5c4(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *, struct _jc_object_array *, struct _jc_object *);

// Virtual methods
extern void _jc_polyglot_util_TransformingIterator$method$findNextItem$9bafc5b15da302df(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);
extern jboolean _jc_polyglot_util_TransformingIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TransformingIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);
extern void _jc_polyglot_util_TransformingIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$findNextItem$9bafc5b15da302df;
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_polyglot_util_TransformingIterator$vmethods {
	void	(*findNextItem$9bafc5b15da302df)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *);
};

// Vtable
struct _jc_polyglot_util_TransformingIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_TransformingIterator$vmethods	polyglot_util_TransformingIterator;
};

// Vtype
struct _jc_polyglot_util_TransformingIterator$vtype {
	_jc_type			type;
	_jc_polyglot_util_TransformingIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TransformingIterator$sub_refs {
	struct _jc_java_lang_Object$object	*next__5fitem;
	struct _jc_object	*current__5fiter;
	_jc_object_array	*backing__5fiterators;
	struct _jc_object	*transformation;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TransformingIterator$refs {
    _jc_polyglot_util_TransformingIterator$sub_refs	polyglot_util_TransformingIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TransformingIterator$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TransformingIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_TransformingIterator$sub_nonrefs	polyglot_util_TransformingIterator;
};

// Object instance structure
struct _jc_polyglot_util_TransformingIterator$object {
	_jc_polyglot_util_TransformingIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TransformingIterator$vtype	*vtype;
	_jc_polyglot_util_TransformingIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TransformingIterator$vtype _jc_polyglot_util_TransformingIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TransformingIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TransformingIterator$class_object;

#endif	/* _JC_polyglot_util_TransformingIterator_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/TransformingIterator.h <==
// public final class polyglot.util.TransformingIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class abf83ac6f164f8b4 polyglot_util_TransformingIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_TransformingIterator_H_
#define _JC_polyglot_util_TransformingIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_Transformation$object;

// Typedefs
typedef struct _jc_polyglot_util_TransformingIterator$sub_refs	_jc_polyglot_util_TransformingIterator$sub_refs;
typedef struct _jc_polyglot_util_TransformingIterator$sub_nonrefs	_jc_polyglot_util_TransformingIterator$sub_nonrefs;
typedef struct _jc_polyglot_util_TransformingIterator$refs	_jc_polyglot_util_TransformingIterator$refs;
typedef struct _jc_polyglot_util_TransformingIterator$nonrefs	_jc_polyglot_util_TransformingIterator$nonrefs;
typedef struct _jc_polyglot_util_TransformingIterator$object	_jc_polyglot_util_TransformingIterator$object;

typedef const struct _jc_polyglot_util_TransformingIterator$vmethods	_jc_polyglot_util_TransformingIterator$vmethods;
typedef const struct _jc_polyglot_util_TransformingIterator$vtable	_jc_polyglot_util_TransformingIterator$vtable;
typedef const struct _jc_polyglot_util_TransformingIterator$vtype	_jc_polyglot_util_TransformingIterator$vtype;

// Constructors
extern void _jc_polyglot_util_TransformingIterator$method$_init$687c4dce38d09c75(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_TransformingIterator$method$_init$8a125fbc5dc09cc2(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_TransformingIterator$method$_init$098c0fa7b235a5c4(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_util_TransformingIterator$method$findNextItem$9bafc5b15da302df(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_TransformingIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TransformingIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_TransformingIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$findNextItem$9bafc5b15da302df;
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_polyglot_util_TransformingIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_polyglot_util_TransformingIterator$vmethods {
	void	(*findNextItem$9bafc5b15da302df)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_polyglot_util_TransformingIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_TransformingIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_TransformingIterator$vmethods	polyglot_util_TransformingIterator;
};

// Vtype
struct _jc_polyglot_util_TransformingIterator$vtype {
	_jc_type			type;
	_jc_polyglot_util_TransformingIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TransformingIterator$sub_refs {
	struct _jc_java_lang_Object$object	*next__5fitem;
	struct _jc_object	*current__5fiter;
	_jc_object_array	*backing__5fiterators;
	struct _jc_object	*transformation;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TransformingIterator$refs {
    _jc_polyglot_util_TransformingIterator$sub_refs	polyglot_util_TransformingIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TransformingIterator$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TransformingIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_TransformingIterator$sub_nonrefs	polyglot_util_TransformingIterator;
};

// Object instance structure
struct _jc_polyglot_util_TransformingIterator$object {
	_jc_polyglot_util_TransformingIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TransformingIterator$vtype	*vtype;
	_jc_polyglot_util_TransformingIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TransformingIterator$vtype _jc_polyglot_util_TransformingIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TransformingIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TransformingIterator$class_object;

#endif	/* _JC_polyglot_util_TransformingIterator_H_ */
